/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { aws_lambda as lambda } from 'aws-cdk-lib';
import * as s3 from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
/**
 * Properties for creating a BdaBlueprintLambda
 */
export interface BdaBlueprintLambdaProps {
    /**
     * The S3 bucket
     * for input data used by the Bedrock Data Automation process.
     * If not provided, a new bucket will be created.
     */
    readonly inputBucket: s3.IBucket;
    /**
     * The layers to apply to this lambda function.
     */
    readonly lambdaLayers: lambda.ILayerVersion[];
}
/**
 * Lambda function that manages BDA blueprint creation
 */
export declare class BdaBlueprintLambda extends lambda.Function {
    constructor(scope: Construct, id: string, props: BdaBlueprintLambdaProps);
}
